# stat-distr

Stat-distr is a Python library for dealing with distribution functions.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stat-distr/) to install foobar.

```bash
pip install stat-distr
```

## Usage

```python
import stat-distr

stat-distr.Gaussian(10,2) # returns Gaussian with mean 10 and stdev 2
stat-distr.Binomial(5,7)  #returns Binomial with probability 5 and size 7
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.